import argparse

from onbbu.cli.cli_run_server import run_server
from onbbu.cli.cli_create_migration import create_migration
from onbbu.cli.cli_apply_migrations import apply_migrations
from onbbu.cli.cli_list_routes import list_routes
from onbbu.settings.ConfigLoader import ConfigLoader
from onbbu.settings.main import BASE_DIR
from onbbu.network.ServerHttp import ServerHttp


module_server: ServerHttp = ConfigLoader(BASE_DIR).load_python_config(
    relative_path="internal/main.py",
    attribute_name="server",
    default=None,
)

def main():

    parser = argparse.ArgumentParser(description="CLI para manejar Onbbu")

    subparsers = parser.add_subparsers(dest="command")

    subparsers.add_parser("run", help="Iniciar el servidor")

    subparsers.add_parser("makemigrations", help="Generar una nueva migración")

    subparsers.add_parser("migrate", help="Aplicar migraciones")

    subparsers.add_parser("routes", help="Listar rutas de")

    args = parser.parse_args()

    if args.command == "run":
        run_server(server=module_server)
    elif args.command == "makemigrations":
        create_migration()
    elif args.command == "migrate":
        apply_migrations()
    elif args.command == "routes":
        list_routes()
    else:
        parser.print_help()


if __name__ == "__main__":
    main()
